@@ -22,9 +22,9 @@ func ListComprehendEntitiesDetectionJobs(sess *session.Session) ([]Resource, err
 			return nil, err
 		}
 		for _, entitiesDetectionJob := range resp.EntitiesDetectionJobPropertiesList {
-			if *entitiesDetectionJob.JobStatus == "STOPPED" ||
-				*entitiesDetectionJob.JobStatus == "FAILED" {
-				// if the job has already been stopped, do not try to delete it again
+			switch *entitiesDetectionJob.JobStatus {
+			case "STOPPED", "FAILED", "COMPLETED":
+				// if the job has already been stopped, failed, or completed; do not try to stop it again
 				continue
 			}
 			resources = append(resources, &ComprehendEntitiesDetectionJob{
