@@ -2,6 +2,7 @@ package resources
 
 import (
 	"fmt"
+	"time"
 
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iam"
@@ -11,6 +12,7 @@ import (
 type IAMUserAccessKey struct {
 	svc         *iam.IAM
 	accessKeyId string
+	createDate  *time.Time
 	userName    string
 	status      string
 	userTags    []*iam.Tag
@@ -47,6 +49,7 @@ func ListIAMUserAccessKeys(sess *session.Session) ([]Resource, error) {
 			resources = append(resources, &IAMUserAccessKey{
 				svc:         svc,
 				accessKeyId: *meta.AccessKeyId,
+				createDate:  meta.CreateDate,
 				userName:    *meta.UserName,
 				status:      *meta.Status,
 				userTags:    userTags.Tags,
@@ -75,6 +78,10 @@ func (e *IAMUserAccessKey) Properties() types.Properties {
 	properties.Set("UserName", e.userName)
 	properties.Set("AccessKeyID", e.accessKeyId)
 
+	if e.createDate != nil {
+		properties.Set("CreateDate", e.createDate.Format(time.RFC3339))
+	}
+
 	for _, tag := range e.userTags {
 		properties.SetTag(tag.Key, tag.Value)
 	}
