@@ -47,6 +47,27 @@ func ListSFNStateMachines(sess *session.Session) ([]Resource, error) {
 }
 
 func (f *SFNStateMachine) Remove() error {
+	params := &sfn.ListExecutionsInput{
+		StateMachineArn: f.ARN,
+	}
+
+	for {
+		executions, execError := f.svc.ListExecutions(params)
+		if execError != nil {
+			break
+		}
+		for _, execs := range executions.Executions {
+
+			f.svc.StopExecution(&sfn.StopExecutionInput{
+				ExecutionArn: execs.ExecutionArn,
+			})
+		}
+
+		if executions.NextToken == nil {
+			break
+		}
+		params.NextToken = executions.NextToken
+	}
 
 	_, err := f.svc.DeleteStateMachine(&sfn.DeleteStateMachineInput{
 		StateMachineArn: f.ARN,
